@@ -292,16 +292,12 @@ _dmap_share_server_start (DMAPShare *share)
 		g_clear_error (&error);
 
 		soup_server_listen_all (share->priv->server, SOUP_ADDRESS_ANY_PORT,
-		                        SOUP_SERVER_LISTEN_IPV6_ONLY, &error);
+		                        0, &error);
 	}
 
 	listening_uri_list = soup_server_get_uris (share->priv->server);
-
-	if (error != NULL || listening_uri_list == NULL) {
-		g_warning ("Unable to start music sharing server on any port: %s. ",
-		           error->message);
-		g_clear_error (&error);
-
+	if (listening_uri_list == NULL) {
+		g_warning ("Unable to start music sharing server on any port.");
 		return FALSE;
 	}
 
